@@ -21,7 +21,6 @@ pub(crate) enum CompileErrorKind<'src> {
     min: usize,
     max: usize,
   },
-  DeprecatedEquals,
   DuplicateAlias {
     alias: &'src str,
     first: usize,
@@ -49,7 +48,7 @@ pub(crate) enum CompileErrorKind<'src> {
   FunctionArgumentCountMismatch {
     function: &'src str,
     found: usize,
-    expected: usize,
+    expected: Range<usize>,
   },
   InconsistentLeadingWhitespace {
     expected: &'src str,
